

PetBattleTeamsUnitFrame = {}

--private static 
local PetBattleTeams =  LibStub("AceAddon-3.0"):GetAddon("PetBattleTeams")
local tooltip = PetBattleTeams:GetModule("Tooltip")
local teamManager = PetBattleTeams:GetModule("TeamManager")
local cursor = PetBattleTeams:GetModule("Cursor")
local Embed = PetBattleTeams.Embed


local menuFrame = CreateFrame("frame", "PetBattleTeamsUnitFrameMenu", UIParent, "UIDropDownMenuTemplate")
menuFrame.menu = {
		{ text = "Team Options",notCheckable = true, isTitle = true },
		{ text = "Rename Team", notCheckable = true,func = function() 
			local teamIndex = menuFrame.teamIndex
			local teamName = teamManager:GetTeamName(teamIndex)
			StaticPopup_Show("PBT_TEAM_RENAME",teamName,nil,teamIndex)
		end 
		},
		{ text = "Delete Team", notCheckable = true,func = function() 
			local teamIndex = menuFrame.teamIndex  
			local teamName = teamManager:GetTeamName(teamIndex)
			StaticPopup_Show("PBT_TEAM_DELETE",teamName,nil,teamIndex)
		end 
		},
	}
	
--event handler for widget
local function OnEvent(self,event,...)
	if event == "PET_JOURNAL_LIST_UPDATE" then
		self:UpdateWidget()
	end
end

-- Local UI widget event handlers
local function OnReceiveDrag(self) 
	local operation, petID, teamIndex, petIndex = cursor:GetCursorInfo()
	if petID then
		if teamIndex and petIndex and operation == "SWAP" then
			TeamManager:UpdateTeamSwapPets(self.teamIndex,self.petIndex,teamIndex, petIndex)
		elseif operation == "COPY" then
			teamManager:UpdateTeamNewPet(petID,self.teamIndex,self.petIndex,teamIndex, petIndex)
		end
	end
	
	if operation == "MOVE TEAM" then
		teamManager:MoveTeam(teamIndex,self.teamIndex)
	end
	ClearCursor()
end

local function OnEnter(self) 
	self:SetTooltip()
end


local function OnLeave(self) 
	tooltip:Hide()
end

local function OnDragStart(self) 
	cursor:PickupPet(self.teamIndex,self.petIndex)
end

local function OnClick(self,button) 
	
	local operation = cursor:GetCursorInfo()
	
	if button == "LeftButton" then
		if operation then
			OnReceiveDrag(self)
		else
			teamManager:SetSelected(self.teamIndex)
		end
	elseif button == "RightButton" then
		self:ShowTeamOptionsMenu()
		tooltip:Hide()
	end
end
-- end widget event handlers
function PetBattleTeamsUnitFrame:SetTooltip()
	local petID, abilities = teamManager:GetPetInfo(self.teamIndex,self.petIndex)
	if petID and petID >0 then
		local teamName = teamManager:GetTeamName(self.teamIndex)
		if tooltip:SetUnit(petID, abilities,teamName) then
			tooltip:Attach(self)
		end
	end
end


function PetBattleTeamsUnitFrame:ShowTeamOptionsMenu()
	local menu = menuFrame.menu
	menuFrame.teamIndex = self.teamIndex
	EasyMenu(menu, menuFrame, "cursor", 0 , 0, "MENU");
end

function PetBattleTeamsUnitFrame:New()
	local self = PetBattleTeamsUnitFrame:CreateWidget()
	Embed(self,PetBattleTeamsUnitFrame)
	
	self:RegisterEvent("PET_JOURNAL_LIST_UPDATE")
	self:SetScript("OnEvent",OnEvent)
	cursor.RegisterCallback(self,"BATTLE_PET_CURSOR_CHANGED")
	self:SetDefaultPet()
	return self
end

function PetBattleTeamsUnitFrame:SetUnitFrameEnabled(enabled)
	
	self.Icon:SetDesaturated(not enabled)
	if self.petID and self.petID > 0 then self.rarityGlow:SetShown(enabled) end
	if enabled then
		self:SetScript("OnReceiveDrag",OnReceiveDrag)
		self:SetScript("OnDragStart",OnDragStart)
		self:SetScript("OnClick",OnClick)
		self.ActualHealthBar:SetVertexColor(0,1,0)
		self.level:SetTextColor(1,.82,1)
	else
		self:SetScript("OnReceiveDrag",nil)
		self:SetScript("OnDragStart",nil)
		self:SetScript("OnClick",nil)
		self.ActualHealthBar:SetVertexColor(.6,.6,.6)
		self.level:SetTextColor(.6,.6,.6)
	end
end

function PetBattleTeamsUnitFrame:CreateWidget()
	local self = CreateFrame("button", nil, nil, "PetBattleMiniUnitFrameAlly")
	self:EnableMouse(true)
	self:RegisterForClicks("LeftButtonUp", "RightButtonUp")
	self:RegisterForDrag("LeftButton")
	
	self.rarityGlow = self:CreateTexture(nil,"ARTWORK") 
	self.rarityGlow:SetTexture("Interface\\Buttons\\UI-ActionButton-Border")
	self.rarityGlow:SetBlendMode("ADD")
	self.rarityGlow:ClearAllPoints()
	self.rarityGlow:SetDrawLayer("ARTWORK", 0)
	self.rarityGlow:SetWidth(self:GetWidth() * 1.5)
	self.rarityGlow:SetHeight(self:GetHeight() * 1.3)
	self.rarityGlow:SetPoint("CENTER", self.Icon, "CENTER", 0, 4)

	self.level = self:CreateFontString(nil,"OVERLAY","GameFontNormalSmall")
	self.level:SetJustifyH("RIGHT")
	self.level:SetText("00")
	self.level:SetSize(0,0)
	self.level:SetFont("Fonts\\FRIZQT__.TTF",11,"OUTLINE")
	self.level:SetPoint("BOTTOMRIGHT",self.Icon,"BOTTOMRIGHT",0,10)
	
	self:SetScript("OnLoad",nil)
	self:SetScript("OnReceiveDrag",OnReceiveDrag)
	self:SetScript("OnDragStart",OnDragStart)
	self:SetScript("OnEnter",OnEnter)
	self:SetScript("OnLeave",OnLeave)
	self:SetScript("OnClick",OnClick)
	return self
end

function  PetBattleTeamsUnitFrame:SetDefaultPet()
	self.level:SetText("XX")
	self.Icon:SetTexture("Interface\\ICONS\\INV_Misc_QuestionMark")
	self.BorderAlive:Hide()
	self.rarityGlow:Hide();
	self.level:Hide()
	self.BorderAlive:Show()
	self.ActualHealthBar:Hide()
	self.BorderDead:Hide()
	self.HealthDivider:Hide()
	self.HealthBarBG:Hide()
	self:Show()
end

function PetBattleTeamsUnitFrame:SetPet(teamIndex,petIndex)
	self.teamIndex = teamIndex
	self.petIndex = petIndex
	if teamIndex > 0 and teamIndex <= teamManager:GetNumTeams() then
		self.petID = teamManager:GetPetInfo(teamIndex,petIndex)
	end
	self:UpdateWidget()

	if tooltip:GetOwner() == self and tooltip:IsShown() then
		self:SetTooltip()
	end
	self:Show()
end

function PetBattleTeamsUnitFrame:UpdateWidget()
	if self.petID and self.petID > 0 then
		local _, _, level, _, _, _, name, icon, _, _, _, _, _, canBattle, _ = C_PetJournal.GetPetInfoByPetID(self.petID)
		local health, maxHealth, _, _, rarity = C_PetJournal.GetPetStats(self.petID)

		if rarity then
			local r, g, b = GetItemQualityColor(rarity-1)
			self.rarityGlow:SetVertexColor(r, g, b)
			self.rarityGlow:Show()
		end
		
		if icon then
			self.Icon:SetTexture(icon)
		else
			self.Icon:SetTexture("Interface\\ICONS\\INV_Misc_QuestionMark")
		end
		
		if level then
			self.level:Show()
			self.level:SetText(level)
		end
		
		if health and health > 0 then
			self.BorderAlive:Show()
			self.ActualHealthBar:Show()
			self.BorderDead:Hide()
			self.HealthDivider:Show()
			self.HealthBarBG:Show()
			self.rarityGlow:SetHeight(self:GetHeight() * 1.3)
			self.rarityGlow:SetPoint("CENTER", self.Icon, "CENTER", 0, 4)
			self.level:SetPoint("BOTTOMRIGHT",self.Icon,"BOTTOMRIGHT",0,10)
			self.ActualHealthBar:SetWidth((health / max(maxHealth,1)) * self.healthBarWidth)
		else
			self.ActualHealthBar:Hide()
			self.BorderAlive:Hide()
			self.BorderDead:Show()
			self.HealthDivider:Hide()
			self.HealthBarBG:Hide()
			self.rarityGlow:SetHeight(self:GetHeight() * 1.7)
			self.rarityGlow:SetPoint("CENTER", self.Icon, "CENTER", 0, 0)
			self.level:SetPoint("BOTTOMRIGHT",self.Icon,"BOTTOMRIGHT",0,0)
		end
	else
		self:SetDefaultPet()
	end
end

function PetBattleTeamsUnitFrame:BATTLE_PET_CURSOR_CHANGED(event,operation,petID,teamIndex,petIndex)
	if teamManager:GetSelected() == self.teamIndex and teamManager:IsTeamLocked(self.teamIndex) then 
		self:SetUnitFrameEnabled(false)
		
	elseif petID and petID > 0 then
		if teamIndex and petIndex and operation == "SWAP" then	
			local containsPet, index = teamManager:TeamContainsPet(self.teamIndex,petID)
			local selfPetID = teamManager:GetPetInfo(self.teamIndex,self.petIndex)
			local sourceContainsDestination = teamManager:TeamContainsPet(teamIndex,selfPetID)
			local enabled = (selfPetID == petID or teamIndex == self.teamIndex) or  (not containsPet and not sourceContainsDestination)
			self:SetUnitFrameEnabled(enabled)
		elseif operation == "COPY" then
			local containsPet = teamManager:TeamContainsPet(self.teamIndex,petID)
			local enabled = not containsPet or petID == teamManager:GetPetInfo(self.teamIndex,self.petIndex)
			self:SetUnitFrameEnabled(enabled)
		end
	else
		self:SetUnitFrameEnabled(true)
	end
end


