local PETS_PER_TEAM = 3
local PetBattleTeams =  LibStub("AceAddon-3.0"):GetAddon("PetBattleTeams")
local teamManager = PetBattleTeams:GetModule("TeamManager")
local Embed = PetBattleTeams.Embed
PetBattleTeamsFrame = {}



local function OnEvent(self,event,...)
	if event == "PET_BATTLE_QUEUE_STATUS" or event == "PET_BATTLE_OPENING_START" or event == "PET_BATTLE_CLOSE" then
		self:PET_BATTLE_QUEUE_STATUS(event,...)
	end
end

function PetBattleTeamsFrame:New()
	local self = CreateFrame("frame")
	Embed(self,PetBattleTeamsFrame)
	
	self.unitFrames = {}
	self.unitFrames[1]= PetBattleTeamsUnitFrame:New()
	self.unitFrames[1]:SetParent(self)
	self.unitFrames[1]:SetPoint("TOPLEFT",self,"TOPLEFT",0,-2)
	
	local width = (self.unitFrames[1]:GetWidth()) * 3
	local height = self.unitFrames[1]:GetHeight() + 2
	self:SetSize(width,height)
	
	for i=2,PETS_PER_TEAM do
		local unitFrame = PetBattleTeamsUnitFrame:New()
		unitFrame:SetParent(self)
		unitFrame:SetPoint("LEFT",self.unitFrames[i-1],"RIGHT",1,0)
		self.unitFrames[i] = unitFrame;
		
	end
	
	
	self.selectedTexture = self:CreateTexture(nil,"OVERLAY") 
	self.selectedTexture:SetSize(36,36)
	self.selectedTexture:SetTexture("Interface\\PetBattles\\PetJournal")
	self.selectedTexture:SetTexCoord(0.11328125,0.16210938,0.02246094,0.04687500)
	self.selectedTexture:SetPoint("CENTER",self,"LEFT",0,0)
	self.selectedTexture:SetParent(self.unitFrames[1])
	self.selectedTexture:Hide()
	
	self.lockedTexture = self:CreateTexture(nil,"OVERLAY") 
	self.lockedTexture:SetSize(30,30)
	self.lockedTexture:SetTexture("Interface\\PetBattles\\PetBattle-LockIcon")
	self.lockedTexture:SetPoint("CENTER",self,"LEFT",0,0)
	self.lockedTexture:SetParent(self.unitFrames[1])
	self.lockedTexture:Hide()
	
	teamManager.RegisterCallback(self,"TEAM_UPDATED")
	teamManager.RegisterCallback(self,"TEAM_DELETED")
	teamManager.RegisterCallback(self,"SELECTED_TEAM_CHANGED")

	self:RegisterEvent("PET_BATTLE_QUEUE_STATUS")
	self:RegisterEvent("PET_BATTLE_OPENING_START","PET_BATTLE_QUEUE_STATUS")
	self:RegisterEvent("PET_BATTLE_CLOSE","PET_BATTLE_QUEUE_STATUS")
	self:SetScript("OnEvent",OnEvent)
	
	return self
end

function PetBattleTeamsFrame:SetTeam(teamIndex)
	self.teamIndex = teamIndex
	
	local isSelected = (teamIndex == teamManager:GetSelected())
	self:SetSelected(isSelected)
	
	for i=1,#self.unitFrames do
		self.unitFrames[i]:SetPet(teamIndex,i)
	end
end

function PetBattleTeamsFrame:SetSelected(selected)
	self.selected = selected
	self:UpdateSelectedIcon()
end

function PetBattleTeamsFrame:UpdateSelectedIcon()
	if self:IsSelected() then
		local showLocked = C_PetBattles.IsInBattle() or C_PetBattles.GetPVPMatchmakingInfo()
		self.selectedTexture:SetShown(not showLocked)
		self.lockedTexture:SetShown(showLocked)
		
		for i=1,#self.unitFrames do
			self.unitFrames[i]:SetUnitFrameEnabled(not showLocked)
		end
		
	else
		self.selectedTexture:Hide()
		self.lockedTexture:Hide()
	end
end

function PetBattleTeamsFrame:IsSelected()
	return self.selected
end

function PetBattleTeamsFrame:TEAM_UPDATED(event,teamIndex)
	if teamIndex == self.teamIndex or teamIndex == nil  then
		self:SetTeam(self.teamIndex)
	end
end

function PetBattleTeamsFrame:TEAM_DELETED(event,teamIndex)
	if teamIndex <= self.teamIndex then
		self:SetTeam(self.teamIndex)
	end
end

function PetBattleTeamsFrame:SELECTED_TEAM_CHANGED(event,teamIndex)
	local isOurTeam = teamIndex == self.teamIndex
	self:SetSelected(isOurTeam)
end

function PetBattleTeamsFrame:PET_BATTLE_QUEUE_STATUS(event, status)
	self:UpdateSelectedIcon()
end

