local PetBattleTeams = LibStub("AceAddon-3.0"):GetAddon("PetBattleTeams")
 Cursor = PetBattleTeams:NewModule("Cursor")
local teamManager = PetBattleTeams:GetModule("TeamManager")
local MAX_DISTANCE = 400

local function OnEvent(self,event,...)
	if event == "BATTLE_PET_CURSOR_CLEAR" then
		Cursor:Clear()
	end
end

local function OnUpdate(self,elapsed)
	self.elapsed = self.elapsed + elapsed
	if self.elapsed > 9 then 
		self.x  = nil
		Cursor:Clear()
		return
	end
	
	local scale = UIParent:GetEffectiveScale() 
	local x, y = GetCursorPosition();
	x = x/scale
	y = y/scale
	
	if not self.x then
		self.x = x
	end
	
	
	local distance = math.abs(self.x - x )
	if distance > MAX_DISTANCE then
		self.x  = nil
		Cursor:Clear()
		return
	end
	
	
	local alpha = 1 - math.min((distance / MAX_DISTANCE), distance - 200 < 0 and 0 or 1)
	self:SetAlpha(alpha)
	
	self:SetPoint("TOPLEFT", UIParent, "BOTTOMLEFT",x+20,y+40)
end

function Cursor:Clear()
	self.teamIndex =nil
	self.petIndex = nil
	self.petID = nil
	self.operation = nil
	if self.teamFrame then self.teamFrame:Hide() end
	self.callbacks:Fire("BATTLE_PET_CURSOR_CHANGED")
end

function Cursor:Initialize()
	self.callbacks = LibStub("CallbackHandler-1.0"):New(self)
	self.teamIndex =nil
	self.petIndex = nil
	self.petID = nil
	self.operation = nil
	self.eventFrame = CreateFrame("frame")
	self.eventFrame:SetScript("OnEvent",OnEvent)
	self.eventFrame:RegisterEvent("BATTLE_PET_CURSOR_CLEAR")
	hooksecurefunc(C_PetJournal,"PickupPet",Cursor.PickupPetHook)
	hooksecurefunc("ClearCursor",Cursor.ClearCursorHook)
end

function Cursor:PickupTeam(teamIndex)
	if not self.teamFrame then
		local teamFrame = PetBattleTeamsFrame:New()
		self.teamFrame = teamFrame
		teamFrame:SetParent(UIParent)
		teamFrame:SetScript("OnUpdate",OnUpdate)
		teamFrame:SetFrameStrata("DIALOG")
	end
	self.teamFrame.elapsed = 0
	self.teamFrame:SetTeam(teamIndex)
	self.teamFrame:Show()
	self.operation = "MOVE TEAM"
	self.teamIndex = teamIndex
	self.petID = nil
	self.petIndex =nil
	
	self.callbacks:Fire("BATTLE_PET_CURSOR_CHANGED",self.operation,nil,teamIndex,nil)
end

function Cursor:PickupPet(teamIndex,petIndex)
	if IsControlKeyDown() then
		Cursor:PickupTeam(teamIndex)
		return
	end

	local petID = teamManager:GetPetInfo(teamIndex,petIndex)
	if self.teamFrame then self.teamFrame:Hide() end
	if petID then
		C_PetJournal.PickupPet(petID)
		self.operation = "SWAP"
		if IsShiftKeyDown() then
			self.operation = "COPY"
		end
		
		self.teamIndex =teamIndex
		self.petIndex = petIndex
		self.petID = petID
		self.callbacks:Fire("BATTLE_PET_CURSOR_CHANGED",self.operation,self.petID,teamIndex,petIndex)
	end
end

function Cursor:GetCursorInfo()
	return self.operation, self.petID, self.teamIndex, self.petIndex
end

function Cursor.PickupPetHook(petID,isWild)
	if Cursor.teamFrame then Cursor.teamFrame:Hide() end
	Cursor.operation = "COPY"
	Cursor.teamIndex =nil
	Cursor.petIndex = nil
	Cursor.petID = petID
	Cursor.callbacks:Fire("BATTLE_PET_CURSOR_CHANGED",Cursor.operation,petID)
end

function Cursor.ClearCursorHook()
	Cursor:Clear()
end

Cursor:Initialize()
