local PetBattleTeams = LibStub("AceAddon-3.0"):GetAddon("PetBattleTeams")
local GUI = PetBattleTeams:GetModule("GUI")
local TeamManager =  PetBattleTeams:GetModule("TeamManager")

local function OnDragStart(self)
	self:StartMoving()
end

local function OnDragStop(self)
	self:StopMovingOrSizing()
	self:SnapToSize()
end

local function SnapToSize(self)
	local left, bottom, width, height = self:GetBoundsRect()
	local teamFrames = self.rosterFrame.scrollChild.teamFrames
	local count = 0
	
	for i=1, #teamFrames do 
		if teamFrames[i]:IsShown() then
			count = count + 1
		end
	end
	
	if left and bottom and height then
		self:SetPoint("TOPLEFT", UIParent, "BOTTOMLEFT", left, bottom+height )
		self:SetPoint("BOTTOMLEFT", UIParent, "BOTTOMLEFT", left, (bottom+height) - (40*count+150) )
	else
		self:SetSize(175,40*count+150)
	end
end

local function SELECTED_TEAM_CHANGED(self,event,teamIndex)
	self.selectedTeam:SetTeam(teamIndex)
end

function GUI:CreateMainFrame()
	local name = "PetBattleTeamFrame"
	local widget = CreateFrame("frame",name,UIParent)
	widget:SetClampedToScreen(true)
	widget:SetFrameStrata("MEDIUM")
	widget:SetToplevel(true) 
	widget:RegisterForDrag("LeftButton")
	widget:SetSize(175,40*11+150)
	widget:SetMaxResize(widget:GetWidth(),40*11+150)
	widget:SetMinResize(widget:GetWidth(),40*4+150)
	widget:SetMovable(true)
	widget:EnableMouse(true)
	
	--widget:SetSize(114+12,38+10)
	--local height = 
	
	widget:SetBackdrop({
      bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
      edgeFile="Interface\\LFGFRAME\\LFGBorder", 
      tile=1, tileSize=16, edgeSize=16, 
      insets={left=5, right=5, top=5, bottom=5}
	  })
	  
	  
	local selectedTeamText = widget:CreateFontString(nil,"OVERLAY","GameFontNormal")
	widget.selectedTeamText = selectedTeamText
	selectedTeamText:SetText("Selected Team")
	selectedTeamText:SetPoint("TOP", widget, "TOP",-5,-10)
	selectedTeamText:SetJustifyH("CENTER")
	selectedTeamText:Show()
	
	local selectedTeam = PetBattleTeamsFrame:New()
	selectedTeam:SetPoint("TOP",selectedTeamText,"BOTTOM",0,0)
	selectedTeam:SetParent(widget)
	selectedTeam:SetTeam(TeamManager:GetSelected())
	widget.selectedTeam = selectedTeam
	
	widget.SELECTED_TEAM_CHANGED = SELECTED_TEAM_CHANGED
	TeamManager.RegisterCallback(widget,"SELECTED_TEAM_CHANGED")
	
	local rosterText = widget:CreateFontString(nil,"OVERLAY","GameFontNormal")
	widget.rosterText = rosterText
	rosterText:SetText("Team Roster")
	rosterText:SetPoint("TOP", selectedTeam, "BOTTOM",0,-10)
	rosterText:SetJustifyH("CENTER")
	rosterText:Show()
	
	
	
	local rosterFrame = self:CreateScrollBar(widget)
	rosterFrame:SetPoint("TOP",rosterText,"BOTTOM",-10,0)
	rosterFrame:SetPoint("BOTTOM",widget,"BOTTOM",-10,60)
	rosterFrame:SetWidth(135)
	widget.rosterFrame = rosterFrame
	
	

	local addTeamButton = self:CreateAddTeamButton("AddTeamButton",widget)
	widget.addTeamButton = addTeamButton
	addTeamButton:SetPoint("TOPLEFT",rosterFrame,"BOTTOMLEFT",18,-6)

	--[[local reviveButton = self:CreateReviveButton("ReviveTeamButton",widget)
	widget.reviveButton = reviveButton
	reviveButton:SetPoint("TOPLEFT",addTeamButton,"TOPRIGHT",1,0)]]
	
	
	local resizer = self:CreateResizer(widget)
	resizer:SetPoint("BOTTOMRIGHT",widget,"BOTTOMRIGHT",-5,5)
	widget.resizer = resizer
	
	widget:SetScript("OnDragStart",OnDragStart)
	widget:SetScript("OnDragStop",OnDragStop)
	widget:SetScript("OnSizeChanged",OnSizeChanged)
	widget.SnapToSize = SnapToSize
	
	
	widget:SnapToSize()
	
	
	
	return widget
end

--[[
local frame = CreateFrame("Frame", name, UIParent)
	frame:SetClampedToScreen(true)
	frame:SetFrameStrata("MEDIUM")
	frame:SetToplevel(true) 
	frame:SetSize(181,614)
	frame:RegisterForDrag("LeftButton")
	frame:EnableMouse(true)
	frame:SetBackdrop({bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border", tile = false, tileSize = 32, edgeSize=32, insets ={left=8,right=8,top=8,bottom=8}})
	frame:SetBackdropColor(.1,.1,.1,1)
	
	frame:SetMaxResize(frame:GetWidth(),frame:GetHeight())
	frame:SetMinResize(frame:GetWidth(),ROW_HEIGHT*1+90)
	
	--frame label
	frame.name = frame:CreateFontString(name.."Title","OVERLAY","GameFontNormal")
	frame.name:SetJustifyH("CENTER")
	frame.name:SetText("Pet Battle Teams")
	frame.name:SetSize(0,0)
	frame.name:SetPoint("CENTER",frame,"TOP",0,-15)
	
	--upper right menu button
	frame.menu = self:CreateMenuButton(name.."Menu",frame)
	frame.menu:SetParent(frame)
	frame.menu:ClearAllPoints()
	frame.menu:SetPoint("TOPRIGHT",frame,"TOPRIGHT",8,8)

	frame.addTeamButton = self:CreateAddTeamButton("PetBattleTeamAddTeamButton",frame)
	frame.addTeamButton:Show()
	frame.petUnitFrames = self:CreatePetUnitFrames(frame)
	frame.revivePetsButton = self:CreateReviveButton("PetBattleTeamReviveButton",frame)
	
	frame.resizeButton = CreateFrame("Button",nil,frame)
	frame.resizeButton:EnableMouse(true)
	frame.resizeButton:SetSize(20,20)
	frame.resizeButton:SetPoint("BOTTOMRIGHT",frame,"BOTTOMRIGHT",-6,6)
	frame.resizeButton.icon = frame.resizeButton:CreateTexture(nil,"ARTWORK")
	frame.resizeButton.icon:SetTexture("Interface\\CHATFRAME\\UI-ChatIM-SizeGrabber-Up")
	frame.resizeButton.icon:SetAllPoints(frame.resizeButton)
	frame.resizeButton:SetHighlightTexture("Interface\\CHATFRAME\\UI-ChatIM-SizeGrabber-Highlight","ADD")
	frame.resizeButton:SetPushedTexture("Interface\\CHATFRAME\\UI-ChatIM-SizeGrabber-Down")
	frame.resizeButton:RegisterForDrag("LeftButton","RightButton")
	--frame.resizeButton:RegisterForClicks("LeftButtonUp","RightButtonUp")
	
	frame.GotoTeamButton = CreateFrame("Frame",nil,frame);
	frame.GotoTeamButton:SetSize(36,36);
	frame.GotoTeamButton:SetPoint("CENTER",frame,"BOTTOM",-6,30)
	frame.GotoTeamButton.icon = frame.GotoTeamButton:CreateTexture(nil,"OVERLAY") 
	frame.GotoTeamButton.icon:SetSize(36,36)
	frame.GotoTeamButton.icon:SetTexture("Interface\\PetBattles\\PetJournal")
	frame.GotoTeamButton.icon:SetTexCoord(0.11328125,0.16210938,0.02246094,0.04687500)
	frame.GotoTeamButton.icon:SetAllPoints(frame.GotoTeamButton)
	frame.GotoTeamButton:EnableMouse(true)
	
	
	--got team button
	frame.GotoTeamButton:SetScript("OnMouseUp",function(self) 
		PetBattleTeamsUI:ScrollToTeam(PetBattleTeamsSettings.selected)
	end)
	
	frame.GotoTeamButton:SetScript("OnEnter",function(self)
		GameTooltip:SetOwner(self, "ANCHOR_BOTTOMRIGHT")
		GameTooltip:ClearLines()
		
		GameTooltip:AddLine("Click to Scroll to your current team")
		
		GameTooltip:Show()
	end)
	frame.GotoTeamButton:SetScript("OnLeave",function(self)
		GameTooltip:Hide()
	end)
	
	
	
	--resizing
	frame:SetScript("OnSizeChanged",function(self) 
		PetBattleTeamsUI:UpdateAllFrames()
	end)
	
	frame.resizeButton:SetScript("OnDragStart",function(self)
		local attached, locked = PetBattleTeamsSettings:GetFrameInfo()
		if not attached and not locked then
			
			frame:SetResizable(true) 
			frame:StartSizing() 
		end
	end)
	frame.resizeButton:SetScript("OnDragStop",function(self)
		frame:StopMovingOrSizing()
		frame:SetResizable(false) 
		
		frame:SetSize(frame:GetWidth(), ROW_HEIGHT*PetBattleTeamsUI:GetMaxRows()+90)
	end)
	return frame
]]